@@ -51,9 +51,6 @@ package com.openexchange.realtime.events.json.actions;
 
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.realtime.events.RTEventManagerService;
 import com.openexchange.realtime.events.json.EventsRequest;
@@ -61,13 +58,9 @@ import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link OffAction}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
-@Action(method = RequestMethod.GET, name = "off", description = "Unsubscribe from a given event", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
-    @Parameter(name = "event", description = "The event to unsubscribe from. If empty, this action unsubscribes the client from all events", optional = true),
-    @Parameter(name = "resource", description = "The resource ID of the client") }, responseDescription = "'true' on success, an error in the appropriate fields otherwise")
 public class OffAction extends AbstractEventAction implements AJAXActionService {
 
     public OffAction(ServiceLookup services) {
